{
    "$graph": [
        {
            "class": "Workflow",
            "doc": "STARR-seq 03 mapping - reads: PE",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "Bedfile containing ENCODE consensus blacklist regions to be excluded.",
                    "type": "File",
                    "id": "#main/ENCODE_blacklist_bedfile"
                },
                {
                    "doc": "Bowtie first index files for reference genome (e.g. *1.bt2). The rest of the files should be in the same folder.",
                    "type": "File",
                    "secondaryFiles": [
                        "^^.2.bt2",
                        "^^.3.bt2",
                        "^^.4.bt2",
                        "^^.rev.1.bt2",
                        "^^.rev.2.bt2"
                    ],
                    "id": "#main/genome_ref_first_index_file"
                },
                {
                    "doc": "Genome sizes tab-delimited file (used in samtools)",
                    "type": "File",
                    "id": "#main/genome_sizes_file"
                },
                {
                    "doc": "Input fastq paired-end read 1 files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_fastq_read1_files"
                },
                {
                    "doc": "Input fastq paired-end read 2 files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_fastq_read2_files"
                },
                {
                    "default": 1,
                    "type": "int",
                    "id": "#main/nthreads"
                },
                {
                    "default": "/usr/picard/picard.jar",
                    "doc": "Picard Java jar file",
                    "type": "string",
                    "id": "#main/picard_jar_path"
                },
                {
                    "doc": "JVM arguments should be a quoted, space separated list (e.g. \"-Xms128m -Xmx512m\")",
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/picard_java_opts"
                },
                {
                    "doc": "Regions bed file used to filter-in reads (used in samtools)",
                    "type": "File",
                    "id": "#main/regions_bed_file"
                }
            ],
            "steps": [
                {
                    "run": "#bedtools-bamtobed.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/bam_to_bepe/bam"
                    ],
                    "in": [
                        {
                            "source": "#main/sort_bams_by_tag_name/sorted_file",
                            "id": "#main/bam_to_bepe/bam"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/bam_to_bepe/bedpe"
                        }
                    ],
                    "out": [
                        "#main/bam_to_bepe/output_bedfile"
                    ],
                    "id": "#main/bam_to_bepe"
                },
                {
                    "run": "#basename.cwl",
                    "scatter": "#main/basename/file_path",
                    "in": [
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/basename/do_not_escape_sep"
                        },
                        {
                            "source": "#main/input_fastq_read1_files",
                            "valueFrom": "$(self.basename)",
                            "id": "#main/basename/file_path"
                        },
                        {
                            "valueFrom": "[\\._]R1",
                            "id": "#main/basename/sep"
                        }
                    ],
                    "out": [
                        "#main/basename/basename"
                    ],
                    "id": "#main/basename"
                },
                {
                    "run": "#bowtie2.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/bowtie2/input_fastq_read1_file",
                        "#main/bowtie2/input_fastq_read2_file",
                        "#main/bowtie2/ungz",
                        "#main/bowtie2/output_filename"
                    ],
                    "in": [
                        {
                            "valueFrom": "${return 2000}",
                            "id": "#main/bowtie2/X"
                        },
                        {
                            "source": "#main/genome_ref_first_index_file",
                            "id": "#main/bowtie2/genome_ref_first_index_file"
                        },
                        {
                            "source": "#main/input_fastq_read1_files",
                            "id": "#main/bowtie2/input_fastq_read1_file"
                        },
                        {
                            "source": "#main/input_fastq_read2_files",
                            "id": "#main/bowtie2/input_fastq_read2_file"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/bowtie2/nthreads"
                        },
                        {
                            "source": "#main/basename/basename",
                            "id": "#main/bowtie2/output_filename"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/bowtie2/sensitive"
                        },
                        {
                            "source": "#main/basename/basename",
                            "valueFrom": "${return self + \".unmmaped.fastq.gz\"}",
                            "id": "#main/bowtie2/ungz"
                        },
                        {
                            "valueFrom": "${return 2}",
                            "id": "#main/bowtie2/v"
                        }
                    ],
                    "out": [
                        "#main/bowtie2/outfile",
                        "#main/bowtie2/output_bowtie_log",
                        "#main/bowtie2/output_unmapped_reads"
                    ],
                    "id": "#main/bowtie2"
                },
                {
                    "run": "#cut.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/cut_to_bepe/input_file"
                    ],
                    "in": [
                        {
                            "valueFrom": "1,2,6",
                            "id": "#main/cut_to_bepe/columns"
                        },
                        {
                            "source": "#main/bam_to_bepe/output_bedfile",
                            "id": "#main/cut_to_bepe/input_file"
                        },
                        {
                            "valueFrom": ".fragments.txt",
                            "id": "#main/cut_to_bepe/suffix"
                        }
                    ],
                    "out": [
                        "#main/cut_to_bepe/output_file"
                    ],
                    "id": "#main/cut_to_bepe"
                },
                {
                    "run": "#extract-basename.cwl",
                    "in": [
                        {
                            "source": "#main/input_fastq_read1_files",
                            "id": "#main/extract_basename_1/input_file"
                        }
                    ],
                    "scatter": "#main/extract_basename_1/input_file",
                    "out": [
                        "#main/extract_basename_1/output_basename"
                    ],
                    "id": "#main/extract_basename_1"
                },
                {
                    "run": "#remove-extension.cwl",
                    "in": [
                        {
                            "source": "#main/extract_basename_1/output_basename",
                            "id": "#main/extract_basename_2/file_path"
                        }
                    ],
                    "scatter": "#main/extract_basename_2/file_path",
                    "out": [
                        "#main/extract_basename_2/output_path"
                    ],
                    "id": "#main/extract_basename_2"
                },
                {
                    "run": "#samtools-view.cwl",
                    "scatter": [
                        "#main/filter_quality_alignments/input_file"
                    ],
                    "in": [
                        {
                            "source": "#main/regions_bed_file",
                            "id": "#main/filter_quality_alignments/L"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/filter_quality_alignments/S"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/filter_quality_alignments/b"
                        },
                        {
                            "valueFrom": "${return 3}",
                            "id": "#main/filter_quality_alignments/f"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/filter_quality_alignments/header"
                        },
                        {
                            "source": "#main/bowtie2/outfile",
                            "id": "#main/filter_quality_alignments/input_file"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/filter_quality_alignments/nthreads"
                        },
                        {
                            "valueFrom": "${return 10}",
                            "id": "#main/filter_quality_alignments/q"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/filter_quality_alignments/u"
                        }
                    ],
                    "out": [
                        "#main/filter_quality_alignments/outfile"
                    ],
                    "id": "#main/filter_quality_alignments"
                },
                {
                    "run": "#samtools-index.cwl",
                    "scatter": [
                        "#main/index_bams/input_file"
                    ],
                    "in": [
                        {
                            "source": "#main/sort_bams/sorted_file",
                            "id": "#main/index_bams/input_file"
                        }
                    ],
                    "out": [
                        "#main/index_bams/indexed_file"
                    ],
                    "id": "#main/index_bams"
                },
                {
                    "run": "#samtools-index.cwl",
                    "scatter": [
                        "#main/index_dedup_bams/input_file"
                    ],
                    "in": [
                        {
                            "source": "#main/sort_dedup_bams/sorted_file",
                            "id": "#main/index_dedup_bams/input_file"
                        }
                    ],
                    "out": [
                        "#main/index_dedup_bams/indexed_file"
                    ],
                    "id": "#main/index_dedup_bams"
                },
                {
                    "run": "#samtools-index.cwl",
                    "scatter": [
                        "#main/index_dups_marked_bams/input_file"
                    ],
                    "in": [
                        {
                            "source": "#main/mark_duplicates/output_dedup_bam_file",
                            "id": "#main/index_dups_marked_bams/input_file"
                        }
                    ],
                    "out": [
                        "#main/index_dups_marked_bams/indexed_file"
                    ],
                    "id": "#main/index_dups_marked_bams"
                },
                {
                    "run": "#samtools-index.cwl",
                    "scatter": [
                        "#main/index_masked_bams/input_file"
                    ],
                    "in": [
                        {
                            "source": "#main/sort_masked_bams/sorted_file",
                            "id": "#main/index_masked_bams/input_file"
                        }
                    ],
                    "out": [
                        "#main/index_masked_bams/indexed_file"
                    ],
                    "id": "#main/index_masked_bams"
                },
                {
                    "run": "#picard-MarkDuplicates.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/mark_duplicates/input_file"
                    ],
                    "in": [
                        {
                            "source": "#main/index_masked_bams/indexed_file",
                            "id": "#main/mark_duplicates/input_file"
                        },
                        {
                            "source": "#main/picard_java_opts",
                            "id": "#main/mark_duplicates/java_opts"
                        },
                        {
                            "valueFrom": "$(inputs.input_file.nameroot + \".dups_marked\")",
                            "id": "#main/mark_duplicates/output_filename"
                        },
                        {
                            "valueFrom": "bam",
                            "id": "#main/mark_duplicates/output_suffix"
                        },
                        {
                            "source": "#main/picard_jar_path",
                            "id": "#main/mark_duplicates/picard_jar_path"
                        }
                    ],
                    "out": [
                        "#main/mark_duplicates/output_metrics_file",
                        "#main/mark_duplicates/output_dedup_bam_file"
                    ],
                    "id": "#main/mark_duplicates"
                },
                {
                    "run": "#preseq-c_curve.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/preseq-c-curve/input_sorted_file"
                    ],
                    "in": [
                        {
                            "source": "#main/index_masked_bams/indexed_file",
                            "id": "#main/preseq-c-curve/input_sorted_file"
                        },
                        {
                            "valueFrom": "$(inputs.input_sorted_file.nameroot + \".preseq_ccurve.txt\")",
                            "id": "#main/preseq-c-curve/output_file_basename"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/preseq-c-curve/pe"
                        }
                    ],
                    "out": [
                        "#main/preseq-c-curve/output_file"
                    ],
                    "id": "#main/preseq-c-curve"
                },
                {
                    "run": "#samtools-view.cwl",
                    "scatter": [
                        "#main/remove_duplicates/input_file"
                    ],
                    "in": [
                        {
                            "valueFrom": "${return 1024}",
                            "id": "#main/remove_duplicates/F"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/remove_duplicates/b"
                        },
                        {
                            "source": "#main/index_dups_marked_bams/indexed_file",
                            "id": "#main/remove_duplicates/input_file"
                        },
                        {
                            "valueFrom": "${return inputs.input_file.basename.replace('dups_marked', 'dedup')}",
                            "id": "#main/remove_duplicates/outfile_name"
                        },
                        {
                            "valueFrom": ".dedup.bam",
                            "id": "#main/remove_duplicates/suffix"
                        }
                    ],
                    "out": [
                        "#main/remove_duplicates/outfile"
                    ],
                    "id": "#main/remove_duplicates"
                },
                {
                    "run": "#bedtools-pairtobed.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/remove_encode_blacklist/abam"
                    ],
                    "in": [
                        {
                            "source": "#main/sort_bams_by_tag_name/sorted_file",
                            "id": "#main/remove_encode_blacklist/abam"
                        },
                        {
                            "source": "#main/ENCODE_blacklist_bedfile",
                            "id": "#main/remove_encode_blacklist/bFile"
                        },
                        {
                            "valueFrom": "neither",
                            "id": "#main/remove_encode_blacklist/type"
                        }
                    ],
                    "out": [
                        "#main/remove_encode_blacklist/filtered"
                    ],
                    "id": "#main/remove_encode_blacklist"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "scatter": [
                        "#main/sort_bams/input_file"
                    ],
                    "in": [
                        {
                            "source": "#main/bowtie2/outfile",
                            "id": "#main/sort_bams/input_file"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/sort_bams/nthreads"
                        }
                    ],
                    "out": [
                        "#main/sort_bams/sorted_file"
                    ],
                    "id": "#main/sort_bams"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "scatter": [
                        "#main/sort_bams_by_tag_name/input_file"
                    ],
                    "in": [
                        {
                            "source": "#main/filter_quality_alignments/outfile",
                            "id": "#main/sort_bams_by_tag_name/input_file"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/sort_bams_by_tag_name/n"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/sort_bams_by_tag_name/nthreads"
                        },
                        {
                            "valueFrom": ".f3q10.nsorted_bam",
                            "id": "#main/sort_bams_by_tag_name/suffix"
                        }
                    ],
                    "out": [
                        "#main/sort_bams_by_tag_name/sorted_file"
                    ],
                    "id": "#main/sort_bams_by_tag_name"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "scatter": [
                        "#main/sort_dedup_bams/input_file"
                    ],
                    "in": [
                        {
                            "source": "#main/remove_duplicates/outfile",
                            "id": "#main/sort_dedup_bams/input_file"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/sort_dedup_bams/nthreads"
                        }
                    ],
                    "out": [
                        "#main/sort_dedup_bams/sorted_file"
                    ],
                    "id": "#main/sort_dedup_bams"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "scatter": [
                        "#main/sort_masked_bams/input_file"
                    ],
                    "in": [
                        {
                            "source": "#main/remove_encode_blacklist/filtered",
                            "id": "#main/sort_masked_bams/input_file"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/sort_masked_bams/nthreads"
                        }
                    ],
                    "out": [
                        "#main/sort_masked_bams/sorted_file"
                    ],
                    "id": "#main/sort_masked_bams"
                },
                {
                    "run": "#sort.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/sort_to_bepe/input_file"
                    ],
                    "in": [
                        {
                            "source": "#main/cut_to_bepe/output_file",
                            "id": "#main/sort_to_bepe/input_file"
                        },
                        {
                            "valueFrom": "$([\"1,1\", \"2,2g\"])",
                            "id": "#main/sort_to_bepe/k"
                        },
                        {
                            "valueFrom": ".bedpe",
                            "id": "#main/sort_to_bepe/suffix"
                        }
                    ],
                    "out": [
                        "#main/sort_to_bepe/outfile"
                    ],
                    "id": "#main/sort_to_bepe"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "doc": "Bowtie log file.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bowtie2/output_bowtie_log",
                    "id": "#main/output_bowtie_log"
                },
                {
                    "doc": "BAM files with aligned reads.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/index_dups_marked_bams/indexed_file",
                    "id": "#main/output_data_bam_files"
                },
                {
                    "doc": "Dedup BAM files with aligned reads.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/index_dedup_bams/indexed_file",
                    "id": "#main/output_data_dedup_bam_files"
                },
                {
                    "doc": "FASTQ gzipped files with unmapped reads.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bowtie2/output_unmapped_reads",
                    "id": "#main/output_data_unmapped_fastq_files"
                },
                {
                    "doc": "Picard MarkDuplicates metrics files.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/mark_duplicates/output_metrics_file",
                    "id": "#main/output_picard_mark_duplicates_files"
                },
                {
                    "doc": "Preseq c_curve output files.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/preseq-c-curve/output_file",
                    "id": "#main/output_preseq_c_curve_files"
                },
                {
                    "doc": "Tags/templates coordinates, sorted by chromosome and position (sort -k1,1 -k2,2g).",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/sort_to_bepe/outfile",
                    "id": "#main/output_templates_files"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/bedtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-i"
                    },
                    "doc": "Input BAM file to be converted to BED format",
                    "id": "#bedtools-bamtobed.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bed12"
                    },
                    "doc": "Write \"blocked\" BED format (aka \"BED12\"). Forces -split.\n",
                    "id": "#bedtools-bamtobed.cwl/bed12"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bedpe"
                    },
                    "doc": "Write BEDPE format.\n- Requires BAM to be grouped or sorted by query.\n",
                    "id": "#bedtools-bamtobed.cwl/bedpe"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-cigar"
                    },
                    "doc": "Add the CIGAR string to the BED entry as a 7th column.\n",
                    "id": "#bedtools-bamtobed.cwl/cigar"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-color"
                    },
                    "doc": "An R,G,B string for the color used with BED12 format.\nDefault is (255,0,0).\n",
                    "id": "#bedtools-bamtobed.cwl/color"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-ed"
                    },
                    "doc": "Use BAM edit distance (NM tag) for BED score.\n- Default for BED is to use mapping quality.\n- Default for BEDPE is to use the minimum of\nthe two mapping qualities for the pair.\n- When -ed is used with -bedpe, the total edit\ndistance from the two mates is reported.\n",
                    "id": "#bedtools-bamtobed.cwl/ed"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-mate1"
                    },
                    "doc": "When writing BEDPE (-bedpe) format, \nalways report mate one as the first BEDPE \"block\".\n",
                    "id": "#bedtools-bamtobed.cwl/mate1"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-split"
                    },
                    "doc": "Report \"split\" BAM alignments as separate BED entries.\nSplits only on N CIGAR operations.\n",
                    "id": "#bedtools-bamtobed.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-splitD"
                    },
                    "doc": "Split alignments based on N and D CIGAR operators.\nForces -split.\n",
                    "id": "#bedtools-bamtobed.cwl/splitD"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-tag"
                    },
                    "doc": "Use other NUMERIC BAM alignment tag for BED score.\n- Default for BED is to use mapping quality.\nDisallowed with BEDPE output.\n",
                    "id": "#bedtools-bamtobed.cwl/tag"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.bed')"
                    },
                    "id": "#bedtools-bamtobed.cwl/output_bedfile"
                }
            ],
            "baseCommand": [
                "bedtools",
                "bamtobed"
            ],
            "stdout": "$(inputs.bam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.bed')",
            "id": "#bedtools-bamtobed.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Tool:    bedtools pairtobed (aka pairToBed)\nVersion: v2.25.0\nSummary: Report overlaps between a BEDPE file and a BED/GFF/VCF file.\n\nUsage:   bedtools pairtobed [OPTIONS] -a <bedpe> -b <bed/gff/vcf>\n\nOptions: \n\t-abam\tThe A input file is in BAM format.  Output will be BAM as well. Replaces -a.\n\t\t- Requires BAM to be grouped or sorted by query.\n\n\t-ubam\tWrite uncompressed BAM output. Default writes compressed BAM.\n\n\t\tis to write output in BAM when using -abam.\n\n\t-bedpe\tWhen using BAM input (-abam), write output as BEDPE. The default\n\t\tis to write output in BAM when using -abam.\n\n\t-ed\tUse BAM total edit distance (NM tag) for BEDPE score.\n\t\t- Default for BEDPE is to use the minimum of\n\t\t  of the two mapping qualities for the pair.\n\t\t- When -ed is used the total edit distance\n\t\t  from the two mates is reported as the score.\n\n\t-f\tMinimum overlap required as fraction of A (e.g. 0.05).\n\t\tDefault is 1E-9 (effectively 1bp).\n\n\t-s\tRequire same strandedness when finding overlaps.\n\t\tDefault is to ignore stand.\n\t\tNot applicable with -type inspan or -type outspan.\n\n\t-S\tRequire different strandedness when finding overlaps.\n\t\tDefault is to ignore stand.\n\t\tNot applicable with -type inspan or -type outspan.\n\n\t-type \tApproach to reporting overlaps between BEDPE and BED.\n\n\t\teither\tReport overlaps if either end of A overlaps B.\n\t\t\t- Default.\n\t\tneither\tReport A if neither end of A overlaps B.\n\t\tboth\tReport overlaps if both ends of A overlap  B.\n\t\txor\tReport overlaps if one and only one end of A overlaps B.\n\t\tnotboth\tReport overlaps if neither end or one and only one \n\t\t\tend of A overlap B.  That is, xor + neither.\n\n\t\tispan\tReport overlaps between [end1, start2] of A and B.\n\t\t\t- Note: If chrom1 <> chrom2, entry is ignored.\n\n\t\tospan\tReport overlaps between [start1, end2] of A and B.\n\t\t\t- Note: If chrom1 <> chrom2, entry is ignored.\n\n\t\tnotispan\tReport A if ispan of A doesn't overlap B.\n\t\t\t\t- Note: If chrom1 <> chrom2, entry is ignored.\n\n\t\tnotospan\tReport A if ospan of A doesn't overlap B.\n\t\t\t\t- Note: If chrom1 <> chrom2, entry is ignored.\n\nRefer to the BEDTools manual for BEDPE format.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/bedtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-S"
                    },
                    "doc": "Require different strandedness when finding overlaps.\nDefault is to ignore stand.\nNot applicable with -type inspan or -type outspan.\n",
                    "id": "#bedtools-pairtobed.cwl/S"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-a"
                    },
                    "doc": "<bedpe>",
                    "id": "#bedtools-pairtobed.cwl/aFile"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-abam"
                    },
                    "doc": "The A input file is in BAM format.  Output will be BAM as well. Replaces -a. - Requires BAM to be grouped or sorted by query. ",
                    "id": "#bedtools-pairtobed.cwl/abam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-b"
                    },
                    "doc": "<bed/gff/vcf>",
                    "id": "#bedtools-pairtobed.cwl/bFile"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bedpe"
                    },
                    "doc": "When using BAM input (-abam), write output as BEDPE. The default\nis to write output in BAM when using -abam.\n",
                    "id": "#bedtools-pairtobed.cwl/bedpe"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-ed"
                    },
                    "doc": "Use BAM total edit distance (NM tag) for BEDPE score.\n- Default for BEDPE is to use the minimum of\nof the two mapping qualities for the pair.\n- When -ed is used the total edit distance\nfrom the two mates is reported as the score.\n",
                    "id": "#bedtools-pairtobed.cwl/ed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "Minimum overlap required as fraction of A (e.g. 0.05).\nDefault is 1E-9 (effectively 1bp).\n",
                    "id": "#bedtools-pairtobed.cwl/f"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Output filename return by this tool\n",
                    "id": "#bedtools-pairtobed.cwl/outfile"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "Require same strandedness when finding overlaps.\nDefault is to ignore stand.\nNot applicable with -type inspan or -type outspan.\n",
                    "id": "#bedtools-pairtobed.cwl/s"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-type"
                    },
                    "doc": "\tApproach to reporting overlaps between BEDPE and BED.\neither\tReport overlaps if either end of A overlaps B.\n- Default.\nneither\tReport A if neither end of A overlaps B.\nboth\tReport overlaps if both ends of A overlap  B.\nxor\tReport overlaps if one and only one end of A overlaps B.\nnotboth\tReport overlaps if neither end or one and only one\nend of A overlap B.  That is, xor + neither.\nispan\tReport overlaps between [end1, start2] of A and B.\n- Note: If chrom1 <> chrom2, entry is ignored.\nospan\tReport overlaps between [start1, end2] of A and B.\n- Note: If chrom1 <> chrom2, entry is ignored.\nnotispan\tReport A if ispan of A doesn't overlap B.\n- Note: If chrom1 <> chrom2, entry is ignored.\nnotospan\tReport A if ospan of A doesn't overlap B.\n- Note: If chrom1 <> chrom2, entry is ignored.\nRefer to the BEDTools manual for BEDPE format.\n",
                    "id": "#bedtools-pairtobed.cwl/type"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-ubam"
                    },
                    "doc": "Write uncompressed BAM output. Default writes compressed BAM.\n",
                    "id": "#bedtools-pairtobed.cwl/ubam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${return inputs.outfile || inputs.abam.basename.replace(/\\.[^/.]+$/, '') + (inputs.bedpe ? '.bedpe' : '.bam')}\n"
                    },
                    "id": "#bedtools-pairtobed.cwl/filtered"
                }
            ],
            "baseCommand": [
                "bedtools",
                "pairtobed"
            ],
            "stdout": "${return inputs.outfile || inputs.abam.basename.replace(/\\.[^/.]+$/, '') + (inputs.bedpe ? '.bedpe' : '.bam')}\n",
            "id": "#bedtools-pairtobed.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "biocontainers/bowtie2:2.2.8",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-D"
                    },
                    "doc": "<int>           give up extending after <int> failed extends in a row (15) ",
                    "id": "#bowtie2.cwl/D"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-I"
                    },
                    "doc": "--minins <int>  minimum fragment length (0)\n",
                    "id": "#bowtie2.cwl/I"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-L"
                    },
                    "doc": "<int>           length of seed substrings; must be >3, <32 (22)\n",
                    "id": "#bowtie2.cwl/L"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-N"
                    },
                    "doc": "<int>           max # mismatches in seed alignment; can be 0 or 1 (0)\n",
                    "id": "#bowtie2.cwl/N"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-R"
                    },
                    "doc": "<int>           for reads w/ repetitive seeds, try <int> sets of seeds (2) Paired-end: ",
                    "id": "#bowtie2.cwl/R"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-X"
                    },
                    "doc": "--maxins <int>  maximum fragment length (500)\n",
                    "id": "#bowtie2.cwl/X"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-a"
                    },
                    "doc": "--all           report all alignments; very slow, MAPQ not meaningful\nEffort:\n",
                    "id": "#bowtie2.cwl/a"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--al"
                    },
                    "doc": "<path>           write unpaired reads that aligned at least once to <path> ",
                    "id": "#bowtie2.cwl/al"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--al-conc"
                    },
                    "doc": "<path>      write pairs that aligned concordantly at least once to <path> (Note: for --un, --al, --un-conc, or --al-conc, add '-gz' to the option name, e.g. ",
                    "id": "#bowtie2.cwl/al-conc"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    },
                    "doc": "                <m1>, <m2>, <r> are sequences themselves, not files ",
                    "id": "#bowtie2.cwl/c"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--dpad"
                    },
                    "doc": "<int>       include <int> extra ref chars on sides of DP table (15)\n",
                    "id": "#bowtie2.cwl/dpad"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--end-to-end"
                    },
                    "doc": "      entire read must align; no clipping (on) [default]",
                    "id": "#bowtie2.cwl/end-to-end"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "                query input files are (multi-)FASTA .fa/.mfa ",
                    "id": "#bowtie2.cwl/f"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--fast"
                    },
                    "doc": "      For --end-to-end: -D 10 -R 2 -N 0 -L 22 -i S,0,2.50; For --local: -D 10 -R 2 -N 0 -L 22 -i S,1,1.75",
                    "id": "#bowtie2.cwl/fast"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--fr"
                    },
                    "doc": "--rf/--ff     -1, -2 mates align fw/rev, rev/fw, fw/fw (--fr)\n",
                    "id": "#bowtie2.cwl/fr"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--gbar"
                    },
                    "doc": "<int>       disallow gaps within <int> nucs of read extremes (4)\n",
                    "id": "#bowtie2.cwl/gbar"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^^.2.bt2",
                        "^^.3.bt2",
                        "^^.4.bt2",
                        "^^.rev.1.bt2",
                        "^^.rev.2.bt2"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-x",
                        "valueFrom": "$(self.path.split('.').splice(0,self.path.split('.').length-2).join(\".\"))"
                    },
                    "doc": "First file (extension .1.bt2) of the Bowtie2 index files generated for the reference genome (see http://bowtie-bio.sourceforge.net/bowtie2/manual.shtml#the-bowtie2-build-indexer)",
                    "id": "#bowtie2.cwl/genome_ref_first_index_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i"
                    },
                    "doc": "<func>          interval between seed substrings w/r/t read len (S,1,1.15) ",
                    "id": "#bowtie2.cwl/i"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ignore-quals"
                    },
                    "doc": "    treat all quality values as 30 on Phred scale (off) ",
                    "id": "#bowtie2.cwl/ignore-quals"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-U"
                    },
                    "doc": "Query input FASTQ file (for single-end samples).",
                    "id": "#bowtie2.cwl/input_fastq_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-1"
                    },
                    "doc": "Query input FASTQ file read 1 (for paired-end samples).",
                    "id": "#bowtie2.cwl/input_fastq_read1_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-2"
                    },
                    "doc": "Query input FASTQ file read 2 (for paired-end samples).",
                    "id": "#bowtie2.cwl/input_fastq_read2_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--int-quals"
                    },
                    "doc": "       qualities encoded as space-delimited integers",
                    "id": "#bowtie2.cwl/int-quals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-k"
                    },
                    "doc": "<int>           report up to <int> alns per read; MAPQ not meaningful\nOR\n",
                    "id": "#bowtie2.cwl/k"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--local"
                    },
                    "doc": "           local alignment; ends might be soft clipped (off)",
                    "id": "#bowtie2.cwl/local"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ma"
                    },
                    "doc": "<int>         match bonus (0 for --end-to-end, 2 for --local) \n",
                    "id": "#bowtie2.cwl/ma"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--met"
                    },
                    "doc": "<int>        report internal counters & metrics every <int> secs (1)\n",
                    "id": "#bowtie2.cwl/met"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--met-file"
                    },
                    "doc": "<path>  send metrics to file at <path> (off)\n",
                    "id": "#bowtie2.cwl/met-file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--met-stderr"
                    },
                    "doc": "      send metrics to stderr (off) ",
                    "id": "#bowtie2.cwl/met-stderr"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--mm"
                    },
                    "doc": "              use memory-mapped I/O for index; many bowtie can share",
                    "id": "#bowtie2.cwl/mm"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--mp"
                    },
                    "doc": "<int>         max penalty for mismatch; lower qual = lower penalty (6)\n",
                    "id": "#bowtie2.cwl/mp"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--n-ceil"
                    },
                    "doc": "<func>    func for max # non-A/C/G/Ts permitted in aln (L,0,0.15)\n",
                    "id": "#bowtie2.cwl/n-ceil"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--no-1mm-upfront"
                    },
                    "doc": "  do not allow 1 mismatch alignments before attempting to scan for the optimal seeded alignments ",
                    "id": "#bowtie2.cwl/no-1mm-upfront"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--no-contain"
                    },
                    "doc": "      not concordant when one mate alignment contains other ",
                    "id": "#bowtie2.cwl/no-contain"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--no-discordant"
                    },
                    "doc": "   suppress discordant alignments for paired reads ",
                    "id": "#bowtie2.cwl/no-discordant"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--no-dovetail"
                    },
                    "doc": "     not concordant when mates extend past each other ",
                    "id": "#bowtie2.cwl/no-dovetail"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--no-head"
                    },
                    "doc": "         suppress header lines, i.e. lines starting with @ ",
                    "id": "#bowtie2.cwl/no-head"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--no-mixed"
                    },
                    "doc": "        suppress unpaired alignments for paired reads ",
                    "id": "#bowtie2.cwl/no-mixed"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--no-overlap"
                    },
                    "doc": "      not concordant when mates overlap at all Output: ",
                    "id": "#bowtie2.cwl/no-overlap"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--no-sq"
                    },
                    "doc": "           suppress @SQ header lines ",
                    "id": "#bowtie2.cwl/no-sq"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--no-unal"
                    },
                    "doc": "         suppress SAM records for unaligned reads ",
                    "id": "#bowtie2.cwl/no-unal"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--nofw"
                    },
                    "doc": "            do not align forward (original) version of read (off) ",
                    "id": "#bowtie2.cwl/nofw"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--non-deterministic"
                    },
                    "doc": "seed rand. gen. arbitrarily instead of using read attributes\n",
                    "id": "#bowtie2.cwl/non-deterministic"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--norc"
                    },
                    "doc": "            do not align reverse-complement version of read (off) ",
                    "id": "#bowtie2.cwl/norc"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--np"
                    },
                    "doc": "<int>         penalty for non-A/C/G/Ts in read/ref (1)\n",
                    "id": "#bowtie2.cwl/np"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--threads"
                    },
                    "doc": "--threads <int> number of alignment threads to launch (1)\n",
                    "id": "#bowtie2.cwl/nthreads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--omit-sec-seq"
                    },
                    "doc": "    put '*' in SEQ and QUAL fields for secondary alignments. Performance: ",
                    "id": "#bowtie2.cwl/omit-sec-seq"
                },
                {
                    "type": "string",
                    "doc": "name of the output file generated",
                    "id": "#bowtie2.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--phred33"
                    },
                    "doc": "         qualities are Phred+33 (default) ",
                    "id": "#bowtie2.cwl/phred33"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--phred64"
                    },
                    "doc": "         qualities are Phred+64 ",
                    "id": "#bowtie2.cwl/phred64"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-q"
                    },
                    "doc": "                query input files are FASTQ .fq/.fastq (default) ",
                    "id": "#bowtie2.cwl/q"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--qc-filter"
                    },
                    "doc": "       filter out reads that are bad according to QSEQ filter ",
                    "id": "#bowtie2.cwl/qc-filter"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--qseq"
                    },
                    "doc": "            query input files are in Illumina's qseq format ",
                    "id": "#bowtie2.cwl/qseq"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--quiet"
                    },
                    "doc": "           print nothing to stderr except serious errors ",
                    "id": "#bowtie2.cwl/quiet"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    },
                    "doc": "                query input files are raw one-sequence-per-line ",
                    "id": "#bowtie2.cwl/r"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--rdg",
                        "shellQuote": false
                    },
                    "doc": "<int>,<int>  read gap open, extend penalties (5,3)\n",
                    "id": "#bowtie2.cwl/rdg"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--reorder"
                    },
                    "doc": "         force SAM output order to match order of input reads ",
                    "id": "#bowtie2.cwl/reorder"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--rfg"
                    },
                    "doc": "<int>,<int>  reference gap open, extend penalties (5,3)\n",
                    "id": "#bowtie2.cwl/rfg"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--rg"
                    },
                    "doc": "<text>        add <text> (\"lab:value\") to @RG line of SAM header.\nNote: @RG line only printed when --rg-id is set.\n",
                    "id": "#bowtie2.cwl/rg"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--rg-id"
                    },
                    "doc": "<text>     set read group id, reflected in @RG line and RG:Z: opt field\n",
                    "id": "#bowtie2.cwl/rg-id"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--score-min"
                    },
                    "doc": "<func> min acceptable alignment score w/r/t read length\n(G,20,8 for local, L,-0.6,-0.6 for end-to-end)\nReporting:\n(default)          look for multiple alignments, report best, with MAPQ\nOR\n",
                    "id": "#bowtie2.cwl/score-min"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seed"
                    },
                    "doc": "<int>       seed for random number generator (0)\n",
                    "id": "#bowtie2.cwl/seed"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sensitive"
                    },
                    "doc": "      For --end-to-end: -D 15 -R 2 -N 0 -L 22 -i S,1,1.15; For --local: -D 15 -R 2 -N 0 -L 20 -i S,1,0.75 (default)",
                    "id": "#bowtie2.cwl/sensitive"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--skip"
                    },
                    "doc": "--skip <int>    skip the first <int> reads/pairs in the input (none)\n",
                    "id": "#bowtie2.cwl/skip"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-t"
                    },
                    "doc": "--time          print wall-clock time taken by search phases\n",
                    "id": "#bowtie2.cwl/t"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--trim3"
                    },
                    "doc": "--trim3 <int>   trim <int> bases from 3'/right end of reads (0)\n",
                    "id": "#bowtie2.cwl/trim3"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--trim5"
                    },
                    "doc": "--trim5 <int>   trim <int> bases from 5'/left end of reads (0)\n",
                    "id": "#bowtie2.cwl/trim5"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--un"
                    },
                    "doc": "<path>           write unpaired reads that didn't align to <path>\n",
                    "id": "#bowtie2.cwl/un"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--un-conc"
                    },
                    "doc": "<path>      write pairs that didn't align concordantly to <path>\n",
                    "id": "#bowtie2.cwl/un-conc"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--un-gz",
                        "shellQuote": false
                    },
                    "doc": "<path>, to gzip compress output, or add '-bz2' to bzip2 compress output.)\n",
                    "id": "#bowtie2.cwl/ungz"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--upto"
                    },
                    "doc": "--upto <int>    stop after first <int> reads/pairs (no limit)\n",
                    "id": "#bowtie2.cwl/upto"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--version"
                    },
                    "doc": "         print version information and quit ",
                    "id": "#bowtie2.cwl/version"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--very-fast"
                    },
                    "doc": "      For --end-to-end: -D 5 -R 1 -N 0 -L 22 -i S,0,2.50; For --local: -D 5 -R 1 -N 0 -L 25 -i S,1,2.00",
                    "id": "#bowtie2.cwl/very-fast"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--very-sensitive"
                    },
                    "doc": "      For --end-to-end: -D 20 -R 3 -N 0 -L 20 -i S,1,0.50; For --local: -D 20 -R 3 -N 0 -L 20 -i S,1,0.50",
                    "id": "#bowtie2.cwl/very-sensitive"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename + '.sam')"
                    },
                    "id": "#bowtie2.cwl/outfile"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename + '.bowtie2.log')"
                    },
                    "id": "#bowtie2.cwl/output_bowtie_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.ungz)"
                    },
                    "id": "#bowtie2.cwl/output_unmapped_reads"
                }
            ],
            "baseCommand": [
                "bowtie2"
            ],
            "stdout": "$(inputs.output_filename + '.sam')",
            "stderr": "$(inputs.output_filename + '.bowtie2.log')",
            "doc": "Bowtie 2 version 2.2.8 by Ben Langmead (langmea@cs.jhu.edu, www.cs.jhu.edu/~langmea)\nUsage:\n  bowtie2 [options]* -x <bt2-idx> {-1 <m1> -2 <m2> | -U <r>} [-S <sam>]\n\n  <bt2-idx>  Index filename prefix (minus trailing .X.bt2).\n             NOTE: Bowtie 1 and Bowtie 2 indexes are not compatible.\n  <m1>       Files with #1 mates, paired with files in <m2>.\n             Could be gzip'ed (extension: .gz) or bzip2'ed (extension: .bz2).\n  <m2>       Files with #2 mates, paired with files in <m1>.\n             Could be gzip'ed (extension: .gz) or bzip2'ed (extension: .bz2).\n  <r>        Files with unpaired reads.\n             Could be gzip'ed (extension: .gz) or bzip2'ed (extension: .bz2).\n  <sam>      File for SAM output (default: stdout)\n\n  <m1>, <m2>, <r> can be comma-separated lists (no whitespace) and can be\n  specified many times.  E.g. '-U file1.fq,file2.fq -U file3.fq'.\n\nOptions (defaults in parentheses):\n\n Input:\n  -q                 query input files are FASTQ .fq/.fastq (default)\n  --qseq             query input files are in Illumina's qseq format\n  -f                 query input files are (multi-)FASTA .fa/.mfa\n  -r                 query input files are raw one-sequence-per-line\n  -c                 <m1>, <m2>, <r> are sequences themselves, not files\n  -s/--skip <int>    skip the first <int> reads/pairs in the input (none)\n  -u/--upto <int>    stop after first <int> reads/pairs (no limit)\n  -5/--trim5 <int>   trim <int> bases from 5'/left end of reads (0)\n  -3/--trim3 <int>   trim <int> bases from 3'/right end of reads (0)\n  --phred33          qualities are Phred+33 (default)\n  --phred64          qualities are Phred+64\n  --int-quals        qualities encoded as space-delimited integers\n\n Presets:                 Same as:\n  For --end-to-end:\n   --very-fast            -D 5 -R 1 -N 0 -L 22 -i S,0,2.50\n   --fast                 -D 10 -R 2 -N 0 -L 22 -i S,0,2.50\n   --sensitive            -D 15 -R 2 -N 0 -L 22 -i S,1,1.15 (default)\n   --very-sensitive       -D 20 -R 3 -N 0 -L 20 -i S,1,0.50\n\n  For --local:\n   --very-fast-local      -D 5 -R 1 -N 0 -L 25 -i S,1,2.00\n   --fast-local           -D 10 -R 2 -N 0 -L 22 -i S,1,1.75\n   --sensitive-local      -D 15 -R 2 -N 0 -L 20 -i S,1,0.75 (default)\n   --very-sensitive-local -D 20 -R 3 -N 0 -L 20 -i S,1,0.50\n\n Alignment:\n  -N <int>           max # mismatches in seed alignment; can be 0 or 1 (0)\n  -L <int>           length of seed substrings; must be >3, <32 (22)\n  -i <func>          interval between seed substrings w/r/t read len (S,1,1.15)\n  --n-ceil <func>    func for max # non-A/C/G/Ts permitted in aln (L,0,0.15)\n  --dpad <int>       include <int> extra ref chars on sides of DP table (15)\n  --gbar <int>       disallow gaps within <int> nucs of read extremes (4)\n  --ignore-quals     treat all quality values as 30 on Phred scale (off)\n  --nofw             do not align forward (original) version of read (off)\n  --norc             do not align reverse-complement version of read (off)\n  --no-1mm-upfront   do not allow 1 mismatch alignments before attempting to\n                     scan for the optimal seeded alignments\n  --end-to-end       entire read must align; no clipping (on)\n   OR\n  --local            local alignment; ends might be soft clipped (off)\n\n Scoring:\n  --ma <int>         match bonus (0 for --end-to-end, 2 for --local)\n  --mp <int>         max penalty for mismatch; lower qual = lower penalty (6)\n  --np <int>         penalty for non-A/C/G/Ts in read/ref (1)\n  --rdg <int>,<int>  read gap open, extend penalties (5,3)\n  --rfg <int>,<int>  reference gap open, extend penalties (5,3)\n  --score-min <func> min acceptable alignment score w/r/t read length\n                     (G,20,8 for local, L,-0.6,-0.6 for end-to-end)\n\n Reporting:\n  (default)          look for multiple alignments, report best, with MAPQ\n   OR\n  -k <int>           report up to <int> alns per read; MAPQ not meaningful\n   OR\n  -a/--all           report all alignments; very slow, MAPQ not meaningful\n\n Effort:\n  -D <int>           give up extending after <int> failed extends in a row (15)\n  -R <int>           for reads w/ repetitive seeds, try <int> sets of seeds (2)\n\n Paired-end:\n  -I/--minins <int>  minimum fragment length (0)\n  -X/--maxins <int>  maximum fragment length (500)\n  --fr/--rf/--ff     -1, -2 mates align fw/rev, rev/fw, fw/fw (--fr)\n  --no-mixed         suppress unpaired alignments for paired reads\n  --no-discordant    suppress discordant alignments for paired reads\n  --no-dovetail      not concordant when mates extend past each other\n  --no-contain       not concordant when one mate alignment contains other\n  --no-overlap       not concordant when mates overlap at all\n\n Output:\n  -t/--time          print wall-clock time taken by search phases\n  --un <path>           write unpaired reads that didn't align to <path>\n  --al <path>           write unpaired reads that aligned at least once to <path>\n  --un-conc <path>      write pairs that didn't align concordantly to <path>\n  --al-conc <path>      write pairs that aligned concordantly at least once to <path>\n  (Note: for --un, --al, --un-conc, or --al-conc, add '-gz' to the option name, e.g.\n  --ungz <path>, to gzip compress output, or add '-bz2' to bzip2 compress output.)\n  --quiet            print nothing to stderr except serious errors\n  --met-file <path>  send metrics to file at <path> (off)\n  --met-stderr       send metrics to stderr (off)\n  --met <int>        report internal counters & metrics every <int> secs (1)\n  --no-unal          suppress SAM records for unaligned reads\n  --no-head          suppress header lines, i.e. lines starting with @\n  --no-sq            suppress @SQ header lines\n  --rg-id <text>     set read group id, reflected in @RG line and RG:Z: opt field\n  --rg <text>        add <text> (\"lab:value\") to @RG line of SAM header.\n                     Note: @RG line only printed when --rg-id is set.\n  --omit-sec-seq     put '*' in SEQ and QUAL fields for secondary alignments.\n\n Performance:\n  -p/--threads <int> number of alignment threads to launch (1)\n  --reorder          force SAM output order to match order of input reads\n  --mm               use memory-mapped I/O for index; many 'bowtie's can share\n\n Other:\n  --qc-filter        filter out reads that are bad according to QSEQ filter\n  --seed <int>       seed for random number generator (0)\n  --non-deterministic seed rand. gen. arbitrarily instead of using read attributes\n  --version          print version information and quit\n",
            "id": "#bowtie2.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/picard",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "BARCODE_TAG=",
                        "separate": false,
                        "position": 5
                    },
                    "doc": "If true do not write duplicates to the output file instead of writing them with appropriate flags set.  (Default false).",
                    "id": "#picard-MarkDuplicates.cwl/barcode_tag"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4,
                        "valueFrom": "$('INPUT=' + self.path)",
                        "shellQuote": false
                    },
                    "doc": "One or more input SAM or BAM files to analyze. Must be coordinate sorted.",
                    "id": "#picard-MarkDuplicates.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": false
                    },
                    "doc": "JVM arguments should be a quoted, space separated list (e.g. \"-Xms128m -Xmx512m\")",
                    "id": "#picard-MarkDuplicates.cwl/java_opts"
                },
                {
                    "type": "string",
                    "default": "dedup_metrics.txt",
                    "doc": "Suffix used to create the metrics output file (Default: dedup_metrics.txt)",
                    "id": "#picard-MarkDuplicates.cwl/metrics_suffix"
                },
                {
                    "type": "string",
                    "doc": "Output filename used as basename",
                    "id": "#picard-MarkDuplicates.cwl/output_filename"
                },
                {
                    "type": "string",
                    "default": "dedup.bam",
                    "doc": "Suffix used to identify the output file (Default: dedup.bam)",
                    "id": "#picard-MarkDuplicates.cwl/output_suffix"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-jar"
                    },
                    "doc": "Path to the picard.jar file",
                    "id": "#picard-MarkDuplicates.cwl/picard_jar_path"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "valueFrom": "$('REMOVE_DUPLICATES=' + self)",
                        "position": 5
                    },
                    "doc": "If true do not write duplicates to the output file instead of writing them with appropriate flags set.  (Default false).",
                    "id": "#picard-MarkDuplicates.cwl/remove_duplicates"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename  + '.' + inputs.output_suffix)"
                    },
                    "id": "#picard-MarkDuplicates.cwl/output_dedup_bam_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename + '.' + inputs.metrics_suffix)"
                    },
                    "id": "#picard-MarkDuplicates.cwl/output_metrics_file"
                }
            ],
            "baseCommand": [
                "java"
            ],
            "arguments": [
                {
                    "valueFrom": "MarkDuplicates",
                    "position": 3
                },
                {
                    "valueFrom": "$('OUTPUT=' + inputs.output_filename + '.' + inputs.output_suffix)",
                    "position": 5,
                    "shellQuote": false
                },
                {
                    "valueFrom": "$('METRICS_FILE='+inputs.output_filename + '.' + inputs.metrics_suffix)",
                    "position": 5,
                    "shellQuote": false
                },
                {
                    "valueFrom": "$('TMP_DIR='+runtime.tmpdir)",
                    "position": 5,
                    "shellQuote": false
                },
                {
                    "valueFrom": "$('USE_JDK_DEFLATER=true')",
                    "position": 5,
                    "shellQuote": false
                },
                {
                    "valueFrom": "$('USE_JDK_INFLATER=true')",
                    "position": 5,
                    "shellQuote": false
                }
            ],
            "id": "#picard-MarkDuplicates.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Usage: c_curve [OPTIONS] <sorted-bed-file>\n\nOptions:\n  -o, -output   yield output file (default: stdout) \n  -s, -step     step size in extrapolations (default: 1e+06) \n  -v, -verbose  print more information \n  -P, -pe       input is paired end read file \n  -H, -hist     input is a text file containing the observed histogram \n  -V, -vals     input is a text file containing only the observed counts \n  -B, -bam      input is in BAM format \n  -l, -seg_len  maximum segment length when merging paired end bam reads \n                (default: 5000) \n\nHelp options:\n  -?, -help     print this help message \n      -about    print about message",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/preseq:2.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-B"
                    },
                    "doc": "-bam      input is in BAM format \n",
                    "id": "#preseq-c_curve.cwl/B"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-H"
                    },
                    "doc": "-hist     input is a text file containing the observed histogram \n",
                    "id": "#preseq-c_curve.cwl/H"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-V"
                    },
                    "doc": "-vals     input is a text file containing only the observed counts \n",
                    "id": "#preseq-c_curve.cwl/V"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Sorted bed or BAM file",
                    "id": "#preseq-c_curve.cwl/input_sorted_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-l"
                    },
                    "doc": "-seg_len  maximum segment length when merging paired end bam reads \n(default: 5000)\nHelp options:\n-?, -help     print this help message\n-about    print about message\n",
                    "id": "#preseq-c_curve.cwl/l"
                },
                {
                    "type": "string",
                    "id": "#preseq-c_curve.cwl/output_file_basename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-P"
                    },
                    "doc": "-pe       input is paired end read file \n",
                    "id": "#preseq-c_curve.cwl/pe"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "-step     step size in extrapolations (default: 1e+06) \n",
                    "id": "#preseq-c_curve.cwl/s"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-v"
                    },
                    "doc": "-verbose  print more information \n",
                    "id": "#preseq-c_curve.cwl/v"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_file_basename + '.preseq_c_curve.txt')"
                    },
                    "id": "#preseq-c_curve.cwl/output_file"
                }
            ],
            "baseCommand": [
                "preseq",
                "c_curve"
            ],
            "stdout": "$(inputs.output_file_basename + '.preseq_c_curve.txt')",
            "id": "#preseq-c_curve.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "listing": [
                        "$(inputs.input_file)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Aligned file to be sorted with samtools",
                    "id": "#samtools-index.cwl/input_file"
                }
            ],
            "outputs": [
                {
                    "doc": "Indexed BAM file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.basename)"
                    },
                    "secondaryFiles": ".bai",
                    "id": "#samtools-index.cwl/indexed_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "index"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.input_file.basename + '.bai')",
                    "position": 2
                }
            ],
            "id": "#samtools-index.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1000
                    },
                    "doc": "Aligned file to be sorted with samtools",
                    "id": "#samtools-sort.cwl/input_file"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-n"
                    },
                    "doc": "Sort by read name",
                    "id": "#samtools-sort.cwl/n"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-@"
                    },
                    "doc": "Number of threads used in sorting",
                    "id": "#samtools-sort.cwl/nthreads"
                },
                {
                    "type": "string",
                    "default": ".sorted.bam",
                    "doc": "suffix of the transformed SAM/BAM file (including extension, e.g. .filtered.sam)",
                    "id": "#samtools-sort.cwl/suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + inputs.suffix)"
                    },
                    "doc": "Sorted aligned file",
                    "id": "#samtools-sort.cwl/sorted_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "stdout": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + inputs.suffix)",
            "arguments": [
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "position": 3,
                    "prefix": "-T"
                }
            ],
            "id": "#samtools-sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-F"
                    },
                    "doc": "only include reads with none of the bits set in INT set in FLAG [0]",
                    "id": "#samtools-view.cwl/F"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-L"
                    },
                    "doc": "FILE  only include reads overlapping this BED FILE [null]",
                    "id": "#samtools-view.cwl/L"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-S"
                    },
                    "doc": "Input format autodetected",
                    "id": "#samtools-view.cwl/S"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-b"
                    },
                    "doc": "output BAM",
                    "id": "#samtools-view.cwl/b"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "only include reads with all bits set in INT set in FLAG [0]",
                    "id": "#samtools-view.cwl/f"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-h"
                    },
                    "doc": "Include header in output",
                    "id": "#samtools-view.cwl/header"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "File to be converted to BAM with samtools",
                    "id": "#samtools-view.cwl/input_file"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-@"
                    },
                    "doc": "Number of threads used",
                    "id": "#samtools-view.cwl/nthreads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Output file name. If not specified, the basename of the input file with the suffix specified in the suffix argument will be used.",
                    "id": "#samtools-view.cwl/outfile_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-q"
                    },
                    "doc": "only include reads with mapping quality >= INT [0]",
                    "id": "#samtools-view.cwl/q"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "suffix of the transformed SAM/BAM file (including extension, e.g. .filtered.sam)",
                    "id": "#samtools-view.cwl/suffix"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-u"
                    },
                    "doc": "uncompressed BAM output (implies -b)",
                    "id": "#samtools-view.cwl/u"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.outfile_name) return inputs.outfile_name;\n  var suffix = inputs.b ? '.bam' : '.sam';\n  suffix = inputs.suffix || suffix;\n  return inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + suffix\n}\n"
                    },
                    "doc": "Aligned file in SAM or BAM format",
                    "id": "#samtools-view.cwl/outfile"
                }
            ],
            "baseCommand": [
                "samtools",
                "view"
            ],
            "stdout": "${\n   if (inputs.outfile_name) return inputs.outfile_name;\n   var suffix = inputs.b ? '.bam' : '.sam';\n   suffix = inputs.suffix || suffix;\n   return inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + suffix\n}\n",
            "id": "#samtools-view.cwl"
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": false,
                    "id": "#basename.cwl/do_not_escape_sep"
                },
                {
                    "type": "string",
                    "id": "#basename.cwl/file_path"
                },
                {
                    "type": "int",
                    "default": 1,
                    "doc": "Number of file extensions to remove",
                    "id": "#basename.cwl/num_ext"
                },
                {
                    "type": "string",
                    "doc": "File extension delimiter",
                    "id": "#basename.cwl/sep"
                }
            ],
            "expression": "${\n  var sep_escaped = !inputs.do_not_escape_sep ? inputs.sep.replace(/[^\\w\\s]/g, \"\\\\$&\") : inputs.sep;\n  var out=inputs.file_path.replace(/^.*[\\\\\\/]/, '');\n  for (var e=0;e<inputs.num_ext; e++){\n    out=out.split(RegExp(\"\\\\b\" + sep_escaped + \"\\\\b\"))[0];\n  }\n  return {\"basename\": out};\n}\n",
            "outputs": [
                {
                    "type": "string",
                    "id": "#basename.cwl/basename"
                }
            ],
            "id": "#basename.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Cut columns from input file.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-f"
                    },
                    "id": "#cut.cwl/columns"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cut.cwl/input_file"
                },
                {
                    "type": "string",
                    "default": ".cut.txt",
                    "id": "#cut.cwl/suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.nameroot + inputs.suffix)"
                    },
                    "id": "#cut.cwl/output_file"
                }
            ],
            "baseCommand": "cut",
            "stdout": "$(inputs.input_file.nameroot + inputs.suffix)",
            "id": "#cut.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Extracts the base name of a file",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#extract-basename.cwl/input_file"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "outputBinding": {
                        "outputEval": "$(inputs.input_file.path.substr(inputs.input_file.path.lastIndexOf('/') + 1, inputs.input_file.path.lastIndexOf('.') - (inputs.input_file.path.lastIndexOf('/') + 1)))"
                    },
                    "id": "#extract-basename.cwl/output_basename"
                }
            ],
            "baseCommand": "echo",
            "id": "#extract-basename.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Extracts the base name of a file",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#remove-extension.cwl/file_path"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "outputBinding": {
                        "outputEval": "$(inputs.file_path.replace(/\\.[^/.]+$/, \"\"))"
                    },
                    "id": "#remove-extension.cwl/output_path"
                }
            ],
            "baseCommand": "echo",
            "id": "#remove-extension.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Usage: sort [OPTION]... [FILE]...\nWrite sorted concatenation of all FILE(s) to standard output.\n\n\nMandatory arguments to long options are mandatory for short options too.\nOrdering options:\n\n\n\n  -b, --ignore-leading-blanks  ignore leading blanks\n\n  -d, --dictionary-order      consider only blanks and alphanumeric characters\n\n  -f, --ignore-case           fold lower case to upper case characters\n\n  -g, --general-numeric-sort  compare according to general numerical value\n\n  -i, --ignore-nonprinting    consider only printable characters\n\n  -M, --month-sort            compare (unknown) < `JAN' < ... < `DEC'\n\n  -n, --numeric-sort          compare according to string numerical value\n\n  -r, --reverse               reverse the result of comparisons\n\n\n\nOther options:\n\n\n\n  -c, --check               check whether input is sorted; do not sort\n\n  -k, --key=POS1[,POS2]     start a key at POS1, end it at POS2 (origin 1)\n\n  -m, --merge               merge already sorted files; do not sort\n\n  -o, --output=FILE         write result to FILE instead of standard output\n\n  -s, --stable              stabilize sort by disabling last-resort comparison\n\n  -S, --buffer-size=SIZE    use SIZE for main memory buffer\n\n  -t, --field-separator=SEP  use SEP instead of non-blank to blank transition\n\n  -T, --temporary-directory=DIR  use DIR for temporaries, not $TMPDIR or /tmp;\n\n                              multiple options specify multiple directories\n\n  -u, --unique              with -c, check for strict ordering;\n\n                              without -c, output only the first of an equal\nrun\n\n  -z, --zero-terminated     end lines with 0 byte, not newline\n\n      --help     display this help and exit\n\n      --version  output version information and exit\n\n\n\nPOS is F[.C][OPTS], where F is the field number and C the character position\nin the field.  OPTS is one or more single-letter ordering options, which\noverride global ordering options for that key.  If no key is given, use the\nentire line as the key.\n\n\nSIZE may be followed by the following multiplicative suffixes:\n% 1% of memory, b 1, K 1024 (default), and so on for M, G, T, P, E, Z, Y.\n\n\nWith no FILE, or when FILE is -, read standard input.\n\n\n*** WARNING ***\nThe locale specified by the environment affects sort order.\nSet LC_ALL=C to get the traditional sort order that uses\nnative byte values.\n\n\nReport bugs to <bug-coreutils@gnu.org>.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-M"
                    },
                    "doc": "--month-sort            compare (unknown) < `JAN' < ... < `DEC'\n",
                    "id": "#sort.cwl/M"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-S"
                    },
                    "doc": "--buffer-size=SIZE    use SIZE for main memory buffer\n",
                    "id": "#sort.cwl/S"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-b"
                    },
                    "doc": "--ignore-leading-blanks  ignore leading blanks\n",
                    "id": "#sort.cwl/b"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    },
                    "doc": "--check               check whether input is sorted; do not sort\n",
                    "id": "#sort.cwl/c"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-d"
                    },
                    "doc": "--dictionary-order      consider only blanks and alphanumeric characters\n",
                    "id": "#sort.cwl/d"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "--ignore-case           fold lower case to upper case characters\n",
                    "id": "#sort.cwl/f"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-g"
                    },
                    "doc": "--general-numeric-sort  compare according to general numerical value\n",
                    "id": "#sort.cwl/g"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i"
                    },
                    "doc": "--ignore-nonprinting    consider only printable characters\n",
                    "id": "#sort.cwl/i"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#sort.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "itemSeparator": " -k ",
                        "prefix": "-k",
                        "shellQuote": false
                    },
                    "doc": "--key=POS1[,POS2]     start a key at POS1, end it at POS2 (origin 1)\n",
                    "id": "#sort.cwl/k"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-m"
                    },
                    "doc": "--merge               merge already sorted files; do not sort\n",
                    "id": "#sort.cwl/m"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-n"
                    },
                    "doc": "--numeric-sort          compare according to string numerical value\n",
                    "id": "#sort.cwl/n"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    },
                    "doc": "--reverse               reverse the result of comparisons\nOther options:\n",
                    "id": "#sort.cwl/r"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "--stable              stabilize sort by disabling last-resort comparison\n",
                    "id": "#sort.cwl/s"
                },
                {
                    "type": "string",
                    "default": ".sorted.txt",
                    "id": "#sort.cwl/suffix"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-t"
                    },
                    "doc": "--field-separator=SEP  use SEP instead of non-blank to blank transition\n",
                    "id": "#sort.cwl/t"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-u"
                    },
                    "doc": "--unique              with -c, check for strict ordering;\nwithout -c, output only the first of an equal run\n",
                    "id": "#sort.cwl/u"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-z"
                    },
                    "doc": "--zero-terminated     end lines with 0 byte, not newline\n",
                    "id": "#sort.cwl/z"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.nameroot + inputs.suffix)"
                    },
                    "id": "#sort.cwl/outfile"
                }
            ],
            "baseCommand": [
                "sort"
            ],
            "stdout": "$(inputs.input_file.nameroot + inputs.suffix)",
            "arguments": [
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "position": 1,
                    "prefix": "--temporary-directory"
                }
            ],
            "id": "#sort.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
